"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const LogLevels_1 = require("./LogLevels");
const padding = (n, width) => {
    const txt = n.toString();
    return txt.length >= width ? txt : `${(new Array(width - txt.length + 1)).join("0")}${txt}`;
};
const ConsoleLogging = (entry, author) => {
    const { level, message, ...meta } = entry;
    const now = new Date();
    const dt = `${now.getUTCFullYear()}-${padding(now.getUTCMonth() + 1, 2)}-${padding(now.getUTCDate(), 2)} ${padding(now.getUTCHours(), 2)}:${padding(now.getUTCMinutes(), 2)}:${padding(now.getUTCSeconds(), 2)}.${padding(now.getUTCMilliseconds(), 3)} GMT`;
    const text = Object.keys(meta).length === 0 ?
        `[${dt}] [AUTHOR:${typeof author === "string" ? author : JSON.stringify(author)}] [${level.toUpperCase()}] - ${message}` :
        `[${dt}] [AUTHOR:${typeof author === "string" ? author : JSON.stringify(author)}] [${level.toUpperCase()}] - ${message} [META:${JSON.stringify(meta)}]`;
    console.log(text);
};
exports.Logging = (author, isInLevel, entry, callback) => {
    if (isInLevel(entry.level)) {
        ConsoleLogging(entry, author);
    }
    if (callback) {
        const { level, message, ...rest } = entry;
        const meta = Object.keys(rest).length === 0 ? undefined : rest;
        callback(author, level, message, meta);
    }
};
const composeLogMethod = (logger, isInLevel) => {
    const author = logger.author;
    const log = (...params) => {
        const [param1, param2, param3, param4] = params;
        let callback;
        let entry;
        if (typeof param1 === "object") {
            entry = param1;
            if (typeof param2 === "function") {
                callback = param2;
            }
        }
        else {
            entry = { level: param1, message: param2 };
            if (typeof param3 === "function") {
                callback = param3;
            }
            else if (typeof param3 === "object") {
                entry = Object.assign(entry, param3);
                if (typeof param4 === "function") {
                    callback = param4;
                }
            }
        }
        exports.Logging(author, isInLevel, entry, callback);
        return logger;
    };
    return Object.defineProperty(logger, "log", {
        configurable: false,
        enumerable: true,
        value: log,
        writable: false,
    });
};
const composeLeveledLogMethod = (logger, isInLevel) => {
    const handleLeveledLog = (Logger, level) => (message, ...params) => {
        const author = Logger.author;
        let callback;
        let entry = { level, message };
        const [param1, param2] = params;
        if (typeof param1 === "function") {
            callback = param1;
        }
        else if (typeof param1 === "object") {
            entry = Object.assign(entry, param1);
            if (typeof param2 === "function") {
                callback = param2;
            }
        }
        exports.Logging(author, isInLevel, entry, callback);
        return Logger;
    };
    return Object.defineProperties(logger, {
        debug: {
            configurable: false,
            enumerable: true,
            value: handleLeveledLog(logger, "debug"),
            writable: false,
        },
        error: {
            configurable: false,
            enumerable: true,
            value: handleLeveledLog(logger, "error"),
            writable: false,
        },
        info: {
            configurable: false,
            enumerable: true,
            value: handleLeveledLog(logger, "info"),
            writable: false,
        },
        warn: {
            configurable: false,
            enumerable: true,
            value: handleLeveledLog(logger, "warn"),
            writable: false,
        },
    });
};
exports.LoggerFactory = (options = {
    author: "LevelLogger",
    level: "warn",
}) => ((Options) => {
    const { author = "LevelLogger" } = Options;
    const isInLevel = LogLevels_1.inLevel(Options.level || "warn");
    const logger = { author };
    composeLogMethod(logger, isInLevel);
    composeLeveledLogMethod(logger, isInLevel);
    Object.freeze(logger);
    return logger;
})(options);
Object.freeze(exports.LoggerFactory);
//# sourceMappingURL=LoggerFactory.js.map