"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const sinon = require("sinon");
const LoggerFactory_1 = require("./LoggerFactory");
describe("LoggerFactory.ts tests", () => {
    describe("#LoggerFactory()", () => {
        it("expect to get a default author", () => {
            const logger = LoggerFactory_1.LoggerFactory();
            const result = logger.author;
            chai_1.expect(result).to.equal("LevelLogger");
        });
        it("expect to get a specified author", () => {
            const author = { module: "Test" };
            const logger = LoggerFactory_1.LoggerFactory({ author });
            const result = logger.author;
            chai_1.expect(result).to.equal(author);
        });
        describe("#logger.log()", () => {
            it("expect to call logger.log() function", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "debug";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.log() function with callback, #1", () => {
                const logger = LoggerFactory_1.LoggerFactory({});
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.log() function with callback, #2", () => {
                const author = { module: "Test" };
                const logger = LoggerFactory_1.LoggerFactory({ author });
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWithExactly(author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.log() function with meta", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "debug";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.log(level, message, meta);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.log() function with meta and callback, #1", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "warn";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.log(level, message, meta, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
            it("expect to call logger.log() function with meta and callback, #2", () => {
                const author = { module: "Test" };
                const logger = LoggerFactory_1.LoggerFactory({ author });
                const level = "warn";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.log(level, message, meta, cb);
                chai_1.expect(cb.calledWithExactly(author, level, message, meta)).to.equal(true);
            });
            it("expect to call logger.log() entry function without callback", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.log({ level, message });
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.log() entry function with callback", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.log({ level, message }, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.log() entry function with meta", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "warn";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.log({ level, message, ...meta }, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
        });
        describe("#level: debug", () => {
            it("expect to call logger.log() function", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "debug";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWith(logger.author, level, message)).to.equal(true);
            });
            it("expect to call logger.debug() function", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const message = "message";
                const cb = sinon.spy();
                logger.debug(message);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.debug() function with callback", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "debug";
                const message = "message";
                const cb = sinon.spy();
                logger.debug(message, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.debug() function with meta and callback", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "debug";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.debug(message, meta, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
        });
        describe("#level: info", () => {
            it("expect to call logger.log() function", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "info";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWith(logger.author, level, message)).to.equal(true);
            });
            it("expect to call logger.info() function", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const message = "message";
                const cb = sinon.spy();
                logger.info(message);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.info() function with callback", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const level = "info";
                const message = "message";
                const cb = sinon.spy();
                logger.info(message, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.info() function with meta", () => {
                const logger = LoggerFactory_1.LoggerFactory();
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.info(message, meta);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.info() function with meta and callback", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "info" });
                const level = "info";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.info(message, meta, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
        });
        describe("#level: warn", () => {
            it("expect to call logger.log() function", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "error" });
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWith(logger.author, level, message)).to.equal(true);
            });
            it("expect to call logger.warn() function", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "error" });
                const message = "message";
                const cb = sinon.spy();
                logger.warn(message);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.warn() function with callback", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "error" });
                const level = "warn";
                const message = "message";
                const cb = sinon.spy();
                logger.warn(message, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.warn() function with meta and callback", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "error" });
                const level = "warn";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.warn(message, meta, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
        });
        describe("#level: error", () => {
            it("expect to call logger.log() function", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "others" });
                const level = "error";
                const message = "message";
                const cb = sinon.spy();
                logger.log(level, message, cb);
                chai_1.expect(cb.calledWith(logger.author, level, message)).to.equal(true);
            });
            it("expect to call logger.error() function", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "others" });
                const message = "message";
                const cb = sinon.spy();
                logger.error(message);
                chai_1.expect(cb.notCalled).to.equal(true);
            });
            it("expect to call logger.error() function with callback", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "others" });
                const level = "error";
                const message = "message";
                const cb = sinon.spy();
                logger.error(message, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, undefined)).to.equal(true);
            });
            it("expect to call logger.error() function with meta and callback", () => {
                const logger = LoggerFactory_1.LoggerFactory({ level: "others" });
                const level = "error";
                const message = "message";
                const meta = { meta: "value" };
                const cb = sinon.spy();
                logger.error(message, meta, cb);
                chai_1.expect(cb.calledWithExactly(logger.author, level, message, meta)).to.equal(true);
            });
        });
    });
});
//# sourceMappingURL=LoggerFactory.spec.js.map